@@ -84,6 +84,7 @@ def SimpleLinearRegression(Independence=None, Dependence=None, df=None, alpha=0.
         'color': '#ffaa77', 'label': f"y = {intercept:.4f} + {slope:.4f} x"})
 
     add_margin(ax, x=kwargs['x'], y=kwargs['y'])  # Call this after tsplot
+    result_dict['fig'] = fig
     result_dict['ax'] = ax
     if plot:
         plt.legend()
@@ -91,6 +92,8 @@ def SimpleLinearRegression(Independence=None, Dependence=None, df=None, alpha=0.
         plt.xlabel(Independence)
         plt.ylabel(Dependence)
         plt.show()
+    else:
+        plt.close(fig)
 
     df_result = smf.ols(f'{Dependence}~ {Independence}', data=df).fit()
     result_dict['result'] = df_result
@@ -120,13 +123,13 @@ Estimated model: y = {intercept:.{precision}f} + {slope:.{precision}f} x
 **** t-Test of Slope <{s_option}> ****
 t (observed value): {s_t_value:.{precision}f}
 t (critical value): {s_t_critical:.{precision}f}
+b1 (slope): {slope:.{precision}f}
 p-value: {s_p_value:.{precision}f} ({inter_p_value(s_p_value)})
 
 Reject H_0 (Has some kind of relationship between two variables) → {s_flag}
 
 {(1-alpha) * 100}% confidence interval = [{ci_b1[0]:.4f}, {ci_b1[1]:.4f}]
 
-
 **** t-Test of Correlation Coefficient <{t_option}> ****
 t (observed value): {t_t_value:.{precision}f}
 t (critical value): {t_t_critical:.{precision}f}
